<?php
function BackupExists($file)
{
  if (file_exists($file))
   return '';
   
  return 'checked disabled';
}

function CanWriteToFile($filename)
{
  if (! @is_writable($filename)) 
  {
     if (! @chmod($filename, 0666)) 
        return (sprintf(INVALID_PERMISSIONS, $filename));
  }
  return '';
}  

function CreateBackup($src, $dest, $backupLocn, $base)
{
  if (! recursive_mkdir($base, $backupLocn))  //create the directories first - if possible
    return (sprintf(MKDIR_FAILED, $src));
  else
  { 
    if (! @copy($src, $dest))
      return (sprintf(BACKUP_FAILED, $src));
  }
  return NULL;  
}

//Handle the line breaks 
function GetCompleteLine($idx, $file, $text)
{
  if (($pos = strpos($text, "');")) !== FALSE) //all text is on one line so just return
  {
    $text = substr($text, 0, $pos);
    return $text;
  }
  
  if (($fpcpy = file($file)) !== FALSE)
  {
    for ($id = $idx + 1; $id < count($fpcpy); ++$id)  //start reading at next line
    {
      if (($pos = strpos($fpcpy[$id], "');")) !== FALSE) //found end of line
      {
        $text .= substr($fpcpy[$id], 0, $pos );  //add to original minus closing php code
        return $text;
      }  
      else
      {
        $text .= $fpcpy[$id]; //add multiple lines
      }    
    }
  }   
  return $text;
}

function IsVariableText($line) //text after the define is not a constant
{
  if (($pos1 = strpos($line, "define('")) !== FALSE) //find the first apostrophe
  {
     $pos1 += strlen("define('");
     if (($pos2 = strpos($line, "'", $pos1)) !== FALSE)
     {
       for ($i = $pos2 + 1; $i < strlen($line); ++$i)  
       {
         if ($line[$i] == "'")
         {
           return true;
         }
       } 
     }   
  }
  return false;              
}

function recursive_mkdir($base, $backupLocn, $mode = 0777) 
{
  $dirs = explode('/' , $backupLocn);
  $count = count($dirs);
  $subDir = '';
  
  for ($i = 0; $i < $count; ++$i) 
  {
    $path = (tep_not_null($subDir)) ? $subDir . '/' . $dirs[$i] : $base . $subDir . $dirs[$i];

    if (!is_dir($path) && !mkdir($path, $mode)) 
      return false;
    else 
      $subDir = $path; 
  }
  return true;
}

function record_sort($records, $field, $reverse=false, $flags=0)
{
  $hash = array();
  
  foreach($records as $key => $record)
  {
    $hash[$record[$field]] = $record;
  }
  
  ($reverse)? krsort($hash, $flags) : ksort($hash, $flags);
  
  $records = array();
  
  foreach($hash as $record)
  {
    $records []= $record;
  }
  
  return $records;
}

function RestoreBackup($src, $dest)
{
  if (! @copy($src, $dest))
    return (sprintf(RESTORE_FAILED, $src));
  return '';
}

function strrpos_str($string, $searchFor, $startFrom = 0) 
{ 
  $addLen = strlen ($searchFor); 
  $endPos = $startFrom - $addLen; 

  while (true) 
  { 
    if (($newPos = strpos ($string, $searchFor, $endPos + $addLen)) === false) break; 
    $endPos = $newPos; 
  } 

  return ($endPos >= 0) ? $endPos : false; 
} 

function SaveText($filename, $fp)
{
  if (!is_writable($filename)) 
  {
     if (!chmod($filename, 0666)) {
        return (sprintf(SAVE_FAILED, $filename));
     }
  }
  
  if ( ! ($fpOut = fopen($filename, "w")))
     return (sprintf(OPEN_FAILED, $filename));
       
  for ($idx = 0; $idx < count($fp); ++$idx)
  {
    if (fwrite($fpOut, $fp[$idx]) === FALSE)
    {
       return (sprintf(WRITE_FAILED, $filename));
    }
  }   
  fclose($fpOut);   
  return '';
}

function SetupArrays(&$fp, $fullPath, &$textArray, &$textString)
{ 
  $lineCtr = 0;
  $foundDefine = false;
  
  if (($fp = file($fullPath)) !== FALSE)
  {
    for ($idx = 0; $idx < count($fp); ++$idx)
    {
      if (($pos1 = strpos($fp[$idx], "define('")) !== FALSE) //find the first apostrophe
      {
        $foundDefine = true;
        $pos1 += strlen("define('");
        if (($pos2 = strpos($fp[$idx], "'", $pos1)) !== FALSE) //find the second apostrophe
        {
          $define = substr($fp[$idx], $pos1, $pos2 - $pos1); 
  
          if (($pos3 = strpos($fp[$idx], "'", $pos2 + 1)) !== FALSE) //find the second apostrophe
          {
            $text = substr($fp[$idx], $pos3 + 1);
            $text = str_replace("\'", "'", GetCompleteLine($idx, $fullPath, $text)); //get the line to display and remove \'s - only for display
            $textArray[$lineCtr++] = array('define' => $define, 'line' => $idx, 'text' => $text);
          }                       
        }
      }
    }
  
    if (! $foundDefine)
    {
        $textString = ''; 
        $textString = (implode('', $fp));
    }
  }
  else
   $messageStack->add(sprintf(OPEN_FAILED, $fullPath), 'error');       
  return $foundDefine;
  }   
?>